@@ -1,5 +1,5 @@
 package QBit::WebInterface;
-$QBit::WebInterface::VERSION = '0.028';
+$QBit::WebInterface::VERSION = '0.029';
 use POSIX qw(strftime setlocale LC_TIME);
 
 use qbit;
@@ -218,7 +218,7 @@ sub _exception2html {
         $dtext =~ s/\\x\{([a-f0-9]{2,})\}/chr(hex($1))/ge;
         $dtext =~ s/;$//msg;
         $dtext =~ s/\n$//msg;
-        Encode::_utf8_on($dtext);
+        utf8::decode($dtext);
 
         return $dtext;
     };
